==> libg%2B%2B-2.2.tar.bz2: libg++-2.2/libg++/etc/trie-gen/main.cc <==
/* Driver routine for the minimal-prefix trie generator.

   Copyright (C) 1989 Free Software Foundation, Inc.
   written by Douglas C. Schmidt (schmidt@ics.uci.edu)
   
   This file is part of GNU TRIE-GEN.
   
   GNU TRIE-GEN is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 1, or (at your option)
   any later version.
   
   GNU TRIE-GEN is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with GNU trie-gen; see the file COPYING.  If not, write to
   the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */

#include <sys/resource.h>
#include <stream.h>
#include "options.h"
#include "trie.h"

int
main (int argc, char **argv)
{
  option (argc, argv);

#ifdef UNLIMIT_STACK
  /* Get rid of any avoidable limit on stack size.  */
  {
    struct rlimit rlim;

    /* Set the stack limit huge so that alloca does not fail. */
    getrlimit (RLIMIT_STACK, &rlim);
    rlim.rlim_cur = rlim.rlim_max;
    setrlimit (RLIMIT_STACK, &rlim);
  }
#endif /* UNLIMIT_STACK */

  Trie  Trie (Trie::DEFAULT_SIZE);
  char *buf;

  for (int i = 0; cin.gets (&buf); i++)
    Trie.insert (buf, cin.gcount ());

  Trie.output ();
}

==> libg%2B%2B-2.4.tar.bz2: libg++-2.4/libg++/etc/trie-gen/main.cc <==
/* Driver routine for the minimal-prefix trie generator.

   Copyright (C) 1989 Free Software Foundation, Inc.
   written by Douglas C. Schmidt (schmidt@ics.uci.edu)
   
   This file is part of GNU TRIE-GEN.
   
   GNU TRIE-GEN is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 1, or (at your option)
   any later version.
   
   GNU TRIE-GEN is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with GNU trie-gen; see the file COPYING.  If not, write to
   the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */

#include <_G_config.h>
#if _G_HAVE_SYS_RESOURCE
#include <sys/resource.h>
#endif
#include <iostream.h>
#include "options.h"
#include "trie.h"

int
main (int argc, char **argv)
{
  option (argc, argv);

#if defined(RLIMIT_STACK) && _G_HAVE_SYS_RESOURCE
  /* Get rid of any avoidable limit on stack size.  */
  {
    struct rlimit rlim;

    /* Set the stack limit huge so that alloca does not fail. */
    getrlimit (RLIMIT_STACK, &rlim);
    rlim.rlim_cur = rlim.rlim_max;
    setrlimit (RLIMIT_STACK, &rlim);
  }
#endif /* RLIMIT_STACK */

  Trie  trie;
  char *buf;

  for (int i = 0; cin.gets (&buf); i++)
    trie.insert (buf, cin.gcount ());

  trie.output ();
}
